package
Version:
v0.5.2
Opens a new window with list of versions in this module.
Published: Dec 10, 2017
License: BSD-3-Clause, GPL-2.0
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func (t *T) Assert(ok bool, msg string, vars ...interface{})
func (t *T) AssertNil(errors ...error)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.